#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2

# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-09-01
# File  : juniper_craft_alarm.py
#
# 2023-09-01: initial release

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    MonitoringState,
    Tuple,
    Integer,
)

from cmk.gui.plugins.wato.utils import (
    rulespec_registry,
    CheckParameterRulespecWithoutItem,
    RulespecGroupCheckParametersHardware,
)


def _parameter_valuespec_vzlogger():
    return Dictionary(
        title=_('Juniper Chassis Alarm'),
        elements=[
            ('state_not_pass_om',
             MonitoringState(
                 title=_('State if Alarm relay mode not "pass on"'),
                 default_value=1,
             )),
            ('state_yellow_not_off',
             MonitoringState(
                 title=_('State if Yellow alarm is not "off"'),
                 default_value=1,
             )),
            ('state_red_not_off',
             MonitoringState(
                 title=_('State if Red alarm is not "off"'),
                 default_value=2,
             )),
            ('count_yellow',
             Tuple(
                 title=_('Levels Yellow Alarm'),
                 help=_(''),
                 elements=[
                     Integer(title=_('Warning at'), minvalue=0, unit=_('')),
                     Integer(title=_('Critical at'), minvalue=0, unit=_('')),
                 ])),
            ('count_red',
             Tuple(
                 title=_('Levels Red Alarm'),
                 help=_(''),
                 elements=[
                     Integer(title=_('Warning at'), minvalue=0, unit=_('')),
                     Integer(title=_('Critical at'), minvalue=0, unit=_('')),
                 ]))

        ],
    )


rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="juniper_craft_alarms",
        group=RulespecGroupCheckParametersHardware,
        parameter_valuespec=_parameter_valuespec_vzlogger,
    ))
